"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.IpcMain = void 0;
const ipc_message_service_1 = require("./ipc-message-service");
class IpcMain {
    constructor() {
        /**
         * 消息处理列表
         */
        this.invokeHandlers = new Map();
        this.message = new ipc_message_service_1.IpcMessageService();
        this.initlize();
    }
    on(method, fn) {
        if (this.invokeHandlers.has(method)) {
            throw new Error(`Attempted to register a second handler for '${method}'`);
        }
        if (typeof fn !== 'function') {
            throw new Error(`Expected handler to be a function, but found type '${typeof fn}'`);
        }
        this.invokeHandlers.set(method, (...args) => __awaiter(this, void 0, void 0, function* () {
            try {
                yield Promise.resolve(fn(...args));
            }
            catch (err) {
                console.log(err);
            }
        }));
    }
    onOnce(method, fn) {
        this.on(method, (...args) => {
            this.remove(method);
            return fn(...args);
        });
    }
    remove(method) {
        this.invokeHandlers.delete(method);
    }
    initlize() {
        this.message.onMessageEvent.subscribe(e => {
            if (this.invokeHandlers.has(e.msg)) {
                const fn = this.invokeHandlers.get(e.msg);
                if (fn) {
                    fn(e.data);
                }
            }
        });
    }
}
exports.IpcMain = IpcMain;
