"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MessageService = void 0;
const rxjs_1 = require("rxjs");
const glob_config_1 = require("./glob-config");
const message_data_1 = require("./message-data");
class MessageService {
    constructor() {
        this.onMessageEvent = new rxjs_1.Subject();
        this.timer = 0;
        /**
         * 已授权的消息列表
         */
        this.authorizationMsg = new Set();
        // 注册服务到window对象上
        ;
        window[glob_config_1.GlobConfig.messageServerName] = this;
        this.capturePluginInfo();
    }
    register(id) {
        console.log(id);
    }
    onMessage(msg, args) {
        const data = new message_data_1.MessageData();
        data.msg = msg;
        data.data = args;
        if (this.isJSON(args)) {
            data.data = JSON.parse(args);
        }
        if (this.authorizationMsg.has(msg)) {
            this.onMessageEvent.next(data);
        }
    }
    isJSON(str) {
        if (typeof str === 'string') {
            try {
                const obj = JSON.parse(str);
                if (typeof obj === 'object' && obj) {
                    return true;
                }
                else {
                    return false;
                }
            }
            catch (e) {
                return false;
            }
        }
    }
    unRegister(id) {
        console.log(id);
    }
    capturePluginInfo() {
        this.timer = setInterval(() => {
            this.pluginInfo = window[glob_config_1.GlobConfig.pluginInfoName];
            if (this.pluginInfo) {
                this.pluginInfo.message.forEach(v => {
                    this.authorizationMsg.add(v);
                });
                clearInterval(this.timer);
            }
        }, 1000);
    }
}
exports.MessageService = MessageService;
