import { IpcMessageService } from './ipc-message-service'

export class IpcMain {
    private message: IpcMessageService
    /**
     * 消息处理列表
     */
    private invokeHandlers: Map<string, (...args: any[]) => void> = new Map()

    constructor() {
        this.message = new IpcMessageService()
        this.initlize()
    }

    on(method: string, fn: (...args: any[]) => void) {
        if (this.invokeHandlers.has(method)) {
            throw new Error(`Attempted to register a second handler for '${method}'`)
        }
        if (typeof fn !== 'function') {
            throw new Error(`Expected handler to be a function, but found type '${typeof fn}'`)
        }
        this.invokeHandlers.set(method, async (...args) => {
            try {
                await Promise.resolve(fn(...args))
            } catch (err) {
                console.log(err)
            }
        })
    }

    onOnce(method: string, fn: (...args: any[]) => void) {
        this.on(method, (...args) => {
            this.remove(method)
            return fn(...args)
        })
    }

    remove(method: string) {
        this.invokeHandlers.delete(method)
    }

    private initlize() {
        this.message.onMessageEvent.subscribe(e => {
            if (this.invokeHandlers.has(e.msg)) {
                const fn = this.invokeHandlers.get(e.msg)
                if (fn) {
                    fn(e.data)
                }
            }
        })
    }
}
