import { Subject } from 'rxjs'
import { IPluginInfo } from '../interface/IPlugin-info'
import { GlobConfig } from './glob-config'
import { IpcMessageData } from './ipc-message-data'

export class IpcMessageService {
    onMessageEvent: Subject<IpcMessageData> = new Subject<IpcMessageData>()

    private pluginInfo: IPluginInfo
    private timer: number = 0
    /**
     * 已授权的消息列表
     */
    private authorizationMsg: Set<string> = new Set<string>()

    constructor() {
        // 注册服务到window对象上
        (window as any)[GlobConfig.messageServerName] = this;
        this.capturePluginInfo()
    }
    register(id: string): void {
        console.log(id)
    }
    onMessage(msg: string, args: string): void {
        const data = new IpcMessageData()
        data.msg = msg
        data.data = args
        if (this.isJSON(args)) {
            data.data = JSON.parse(args)
        }
        if (this.authorizationMsg.has(msg)) {
            this.onMessageEvent.next(data)
        }
    }

    isJSON(str: string) {
        if (typeof str === 'string') {
            try {
                const obj = JSON.parse(str)
                if (typeof obj === 'object' && obj) {
                    return true
                } else {
                    return false
                }
            } catch (e) {
                return false
            }
        }
    }

    unRegister(id: string): void {
        console.log(id)
    }
    private capturePluginInfo() {
        this.timer = setInterval(() => {
            this.pluginInfo = (window as any)[GlobConfig.pluginInfoName] as IPluginInfo
            if (this.pluginInfo) {
                this.pluginInfo.message.forEach(v => {
                    this.authorizationMsg.add(v)
                })
                clearInterval(this.timer)
            }
        }, 1000)
    }
}
