import { IMessage } from "../interface/IMessage";
import { GlobConfig } from "../Ipc-main/glob-config";

export interface IMessageInstance {
  send(msg: string): Promise<string>;
}

export class NetService {
  private get messageService(): IMessageInstance {
    return (window as any)[GlobConfig.netMessageBridgeService] as IMessageInstance;
  }

  async send(msg: IMessage): Promise<any> {
    if (!this.messageService) {
      return Promise.reject("net service not inject");
    }
    if (!msg) {
      return Promise.reject("net service not inject");
    }
    const data = JSON.stringify(msg);
    const result = await this.messageService.send(data);
    const isjson=this.isJSON(result)
    if(isjson){
      return Promise.resolve(JSON.parse(result));
    }else{
      return Promise.resolve(result);
    }
  }

  isJSON(str: string) {
    if (typeof str === 'string') {
        try {
            const obj = JSON.parse(str)
            if (typeof obj === 'object' && obj) {
                return true
            } else {
                return false
            }
        } catch (e) {
            return false
        }
    }
}
}